
Changelog
=========

0.1.4 (2022-04-15)
------------------
* Fixed message generation/parsing for addresses 11 through 16

0.1.3 (2021-07-25)
------------------
* Fixed support for multiple instances where the parameter data type is an integer

0.1.2 (2021-01-13)
------------------
* added support for multiple instances, like in the RM series controllers with multiple channels

0.1.1 (2020-08-15)
------------------

* Initial PyPI release
* Various tox, badge, and metadata fixes
* Removed unused temperature unit conversion functions
* Updated Python version requirements
* Minor documentation clean up

0.1.0 (2020-08-08)
------------------

* Added basic functionality

  * Reading/writing of Watlow parameters
  * Request message generation
  * Calculation of check bytes
  * Response message parsing
